@@ -2,7 +2,7 @@
 #-------------------------------------------------------------------------
 # Module: Gbook
 # Author: Jos (josvd@live.nl)
-# Version: 2.2.6
+# Version: 2.3
 #
 #-------------------------------------------------------------------------
 # CMS - CMS Made Simple is (c) 2009 by Ted Kulp (wishy@cmsmadesimple.org)
@@ -43,7 +43,7 @@ class Gbook extends CMSModule
 
 	function GetVersion()
 	{
-		return '2.2.6';
+		return '2.3';
 	}
 
 	function GetHelp()
@@ -103,7 +103,7 @@ class Gbook extends CMSModule
 
 	function MinimumCMSVersion()
 	{
-		return "1.12";
+		return "2.2";
 	}
 
 	function InitializeFrontend()
