@@ -16,7 +16,7 @@ $alias = empty($params['alias']) ? $this->GetPreference('defaultgbook') : $param
 $gbooks = Gbook_utils::GetGbooks($alias);
 if (!empty($gbooks))
 {
-	$gbook = $gbooks[0];
+	$gbook = current($gbooks);
 	$smarty->assign('gbook_props', $gbook);
 
 
@@ -51,7 +51,7 @@ if (!empty($gbooks))
 		for ($i = 1; $i <= $pages; $i++)
 		{
 			$linkparams['gbpage'] = $i;
-			$pagelinks[$i] = $this->CreateFrontendLink($id, $returnid, 'default', '', $linkparams, '', true, true, '', false); //, $prettyurl . $i . '/' . $returnid);
+			$pagelinks[] = $this->CreateFrontendLink($id, $returnid, 'default', '', $linkparams, '', true, true, '', false); //, $prettyurl . $i . '/' . $returnid);
 		}
 		$smarty->assign('gbook_pagelinks', $pagelinks);
 		$smarty->assign('gbook_currentpage', $params['gbpage']);
