@@ -39,7 +39,7 @@ if( isset($params['cancel']) )
 // Get gbook properties
 $alias = empty($params['alias']) ? $this->GetPreference('defaultgbook') : $params['alias'];
 $gbooks = Gbook_utils::GetGbooks($alias);
-$gbook = $gbooks[0];
+$gbook = current($gbooks);
 
 if ( empty($gbook) )
 {
@@ -47,7 +47,7 @@ if ( empty($gbook) )
 }
 
 // token
-$token = $this->GetPreference('gbook_token', 's:0:"";');
+$token = $this->GetPreference('gbook_token', 'a:1:{i:0;s:0:"";}');
 $token = unserialize($token);
 $tokentimestamp = ceil(time()/60/5);
 if ( empty($token[$tokentimestamp]) ) 
@@ -81,47 +81,53 @@ if( $_SERVER['REQUEST_METHOD'] == 'POST' && isset($params['submit']) )
 		{
 			// entry added succesfully
 			
-			//$entry_id = $addentry['entry added'][0];
+			$entry_id = $addentry['entry added'][0];
 			$spamrate = $addentry['entry added'][1];
 			if ( $spamrate <= $this->GetPreference('max_spamrate_notify', 0.9) )
 			{
 				// send email to admin
-				global $CMS_VERSION;
-				if ($CMS_VERSION >= 2) {
-					$cmsmailer = new cms_mailer;
-				}
-				else
-				{
-					$cmsmailer = cms_utils::get_module('CMSMailer');					
-				}
-				$users = (array)unserialize($this->GetPreference('send_notifications_to'));
-				if( $cmsmailer && !empty($users) )
-				{
-					foreach ( $users as $user )
-					{
-						if ( $user < 0 )
-						{
-							// group
-							$groupusers = cmsms()->GetUserOperations()->LoadUsersInGroup(abs($user));
-							foreach ( $groupusers as $groupuser)
-							{
-								if ( $groupuser->active ) $cmsmailer->AddAddress($groupuser->email);
-							}
-						}
-						else
-						{
-							// individual user
-							$user_email = cmsms()->GetUserOperations()->LoadUserById($user)->email;
-							$cmsmailer->AddAddress($user_email);
-						}
-					}
-					$cmsmailer->SetSubject($gbook['admin_notification_subject']);
-					$cmsmailer->IsHTML(false);
-					$body = $smarty->fetch('string:'.$gbook['admin_notification_message']);
-					$cmsmailer->SetBody($body);
-					$cmsmailer->Send();
-					$cmsmailer->ClearAddresses();
-				}				
+        try {
+          $cmsmailer = new cms_mailer;
+          $users = (array)unserialize($this->GetPreference('send_notifications_to'));
+          if( $cmsmailer && !empty($users) )
+          {
+            try {
+              foreach ( $users as $user )
+              {
+                if ( $user < 0 )
+                {
+                  // group
+                  $groupusers = cmsms()->GetUserOperations()->LoadUsersInGroup(abs($user));
+                  foreach ( $groupusers as $groupuser)
+                  {
+                    if ( $groupuser->active ) $cmsmailer->AddAddress($groupuser->email);
+                  }
+                }
+                else
+                {
+                  // individual user
+                  $user_email = cmsms()->GetUserOperations()->LoadUserById($user)->email;
+                  $cmsmailer->AddAddress($user_email);
+                }
+              }
+              $cmsmailer->SetSubject($gbook['admin_notification_subject']);
+              $cmsmailer->IsHTML(false);
+              $body = $smarty->fetch('string:'.$gbook['admin_notification_message']);
+              $cmsmailer->SetBody($body);
+              $cmsmailer->Send();
+            }
+            catch (Exception $e) {
+              debug_to_log($e->getMessage());
+            }
+            finally {
+              $cmsmailer->ClearAddresses();
+            }
+          }
+        }
+        catch (Exception $e) {
+          audit($entry_id, $this->GetName(), $lang['send_notifications_to'] . ' - ' . $e->getMessage());
+        }
+
 			}
 			
 			// display submission response
@@ -224,9 +230,9 @@ elseif( $_SERVER['REQUEST_METHOD'] == 'POST' && isset($params['validate']) )
 	$captcha = cms_utils::get_module('Captcha');
 	if ( $captcha && !empty($_SESSION['gbook_entry']) )
 	{
-		$captcha_needsinput = method_exists($captcha, 'NeedsInputField') ? $captcha->NeedsInputField() : true;        
-        $tovalidate = $captcha_needsinput ? $params['captcha_input'] : '';
-		$validated = $captcha->checkCaptcha($tovalidate);
+    $captcha_needsinput = method_exists($captcha, 'NeedsInputField') ? $captcha->NeedsInputField() : true;        
+    $tovalidate = $captcha_needsinput ? $params['captcha_input'] : '';
+    $validated = $captcha->checkCaptcha($tovalidate);
 	}
 	else
 	{
@@ -241,6 +247,7 @@ elseif( $_SERVER['REQUEST_METHOD'] == 'POST' && isset($params['validate']) )
 	}
 	else
 	{
+		Gbook_utils::ActivateEntry($_SESSION['gbook_entry'], 0); // deactivate
 		$smarty->assign('gbook_captcha', '');
 		$smarty->assign('gbook_captcha_input', '');
 		echo $smarty->display('string:'.$gbook['submission_response_spam']);		
@@ -253,6 +260,8 @@ if ( $showform )
 	// build the form
 	$smarty->assign('gbook_name', $gbook['name']);
 	$smarty->assign('gbook_formid', $id);
+  
+	$smarty->assign('gbook_formparams', array('alias' => $gbook['gbook_id'], 'token' => $tokentimestamp . '-' . md5($gbook['gbook_id'] . $token[$tokentimestamp]) ));
 	
 	$smarty->assign('gbook_errormessage', empty($fielderrors) ? '' : $this->Lang('validation_errors'));
 	$smarty->assign('gbook_startform', $this->CreateFrontEndFormStart($id, $returnid, 'form', 'post', 'multipart/form-data', true, '', array('alias' => $gbook['gbook_id'], 'token' => $tokentimestamp . '-' . md5($gbook['gbook_id'] . $token[$tokentimestamp]) )));
@@ -310,7 +319,8 @@ if ( $showform )
 		$template = 'form_tpl_' . $params['template'];
 	}
 		
-	echo $this->ProcessTemplateFromDatabase($template);
+	//echo $this->ProcessTemplateFromDatabase($template);
+	$smarty->display($this->GetDatabaseResource($template));
 }
 
 ?>
\ No newline at end of file
