@@ -32,6 +32,6 @@ $params['badwords'] = str_replace(' ,', ',', $params['badwords']);
 $params['badwords'] = trim($params['badwords'], ',');
 $this->SetPreference('badwords', trim($params['badwords']));
 
-$params = array('tab_message'=> 'optionsupdated', 'active_tab' => 'options');
+$params = array('tab_message'=> $this->Lang('optionsupdated'), 'active_tab' => 'options');
 $this->Redirect($id, 'defaultadmin', '', $params);
 ?>
