@@ -49,6 +49,5 @@ $smarty->assign('input_badwords', $this->	CreateTextArea (false, $id, $this->Get
 $smarty->assign('submit', $this->CreateInputSubmit ($id, 'optionssubmitbutton', lang('submit')));
 
 // Display the populated template
-echo $this->ProcessTemplate ('adminoptions.tpl');
-
+$smarty->display($this->GetTemplateResource('adminoptions.tpl'));
 ?>
\ No newline at end of file
