@@ -68,6 +68,5 @@ $smarty->assign('newtemplatelink',
 			     lang('addtemplate'),
 			     array('mode' => 'add', 'defaulttemplatepref' => 'default_template_contents')));
 
-echo $this->ProcessTemplate('admintemplates.tpl');
-
+$smarty->display($this->GetTemplateResource('admintemplates.tpl'));
 ?>
\ No newline at end of file
