@@ -115,13 +115,12 @@ Users must belong to a group with the \'Gbook: Modify\' permission to be able to
 <h3>Support</h3>
 <p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
 <ul>
-<li>FAQs, extended module help and Troubleshooting can be found in the <a href="http://wiki.cmsms.nl/index.php/Gbook">Gbook Wiki Documentation</a>.</li>
 <li>For the latest version of this module or to file a Feature Request or Bug Report, please visit the Module Forge
 <a href="http://dev.cmsmadesimple.org/projects/gbook/">Gbook Page</a>.</li>
-<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>. You are warmly invited to open a new topic if you didn\'t find an answer to your question.</li>
+<li>Additional discussion of this module may also be found in the <a href="https://forum.cmsmadesimple.org">CMS Made Simple Forums</a>. You are warmly invited to open a new topic if you didn\'t find an answer to your question.</li>
 <li>Lastly, you may have some success emailing the author directly.</li>
 </ul>
 
 <h3>Feedback</h3>
-<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="http://forum.cmsmadesimple.org/viewtopic.php?f=7&t=64460">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>';
+<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="https://forum.cmsmadesimple.org/viewtopic.php?f=7&t=64460">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>';
 ?>
\ No newline at end of file
