@@ -16,10 +16,14 @@ class Gbook_utils
 	public static function GetGbooks($gbook = '', $filter = true) {
 		$output = array();
 		
+		$mod = cms_utils::get_module('Gbook');
 		$db = cmsms()->GetDB();
 		$query = "SELECT
 								g.*,
 								COUNT(e.entry_id) AS entries,
+                SUM(IF(e.active = 1,1,0)) AS active_entries,
+                SUM(IF(e.active = 0,1,0)) AS inactive_entries,
+                SUM(IF(e.spamrate >= " . $db->Qmagic($mod->GetPreference('max_spamrate_active', 0.5) * 100) . ",1,0)) AS spam_entries,
 								COUNT(e.rating) AS ratings,
 								AVG(e.rating) AS rating_average
 							FROM
@@ -52,7 +56,7 @@ class Gbook_utils
 			$query .= "AND g.active = 1
 								";
 		}
-		$query .= "GROUP BY
+    $query .= "GROUP BY
 								g.gbook_id";
 		if ( empty($gbook) )
 		{
@@ -66,7 +70,7 @@ class Gbook_utils
 		{
 		  while ( $row=$result->FetchRow() )
 		  {
-		    $output[] = $row;
+		    $output[$row['gbook_id']] = $row;
 		  }
 		}
 		if ( !$result )
@@ -393,9 +397,9 @@ class Gbook_utils
 	}
 
 	
-	public static function ActivateEntry($entry_id) {
+	public static function ActivateEntry($entry_id, $entry_status = 1) {
 		$entry = self::GetEntry($entry_id);
-		self::EditEntry($entry_id, $entry->gbook_id, $entry->name, $entry->email, $entry->title, $entry->rawmessage, $entry->notify, 1);
+		self::EditEntry($entry_id, $entry->gbook_id, $entry->name, $entry->email, $entry->title, $entry->rawmessage, $entry->notify, $entry_status);
 	}
 
 	
@@ -488,6 +492,7 @@ class Gbook_utils
 	
 	
 	public static function GetSmileys($filter = true) {
+    $mod = cms_utils::get_module('Gbook');
 		$smileyscache = cms_utils::get_app_data('gbook_smileys_'.$filter);
 		if ( empty($smileyscache) )
 		{
@@ -513,7 +518,7 @@ class Gbook_utils
 				while ( $row=$result->FetchRow() )
 				{
 					$output[$row['smiley_id']] = $row;
-					$output[$row['smiley_id']]['smiley_path'] = 'modules/Gbook/smileys/' . $row['smiley_file'];
+					$output[$row['smiley_id']]['smiley_path'] = $mod->GetModuleURLPath() . '/smileys/' . $row['smiley_file'];
 				}
 				cms_utils::set_app_data('gbook_smileys_'.$filter, serialize($output));
 			}
