@@ -123,7 +123,7 @@ $result = $db->Execute($query, array(
 $this->SetPreference('defaultgbook', 1);
 
 // fill smileys dir, only if there aren't any images already.
-$images = glob("../modules/Gbook/smileys/*.{jpg,JPG,png,PNG}", GLOB_BRACE);
+$images = glob(cms_join_path($this->GetModulePath(), 'smileys', '*.{jpg,JPG,png,PNG}'), GLOB_BRACE);
 //debug_display($images, 'Start Smileys');
 if ( empty($images) )
 {
@@ -188,26 +188,12 @@ foreach ( $templates as $template )
 // setup sample stylesheet
 $fn = cms_join_path(dirname(__FILE__), 'templates', 'stylesheet.css');
 $txt = file_get_contents($fn);
-if (version_compare(CMS_VERSION, '1.99-alpha0', '<'))
-{
-    $stylesheetops = cmsms()->GetStylesheetOperations();
-    if( !$stylesheetops->CheckExistingStylesheetName('Gbook module') )
-    {
-        $stylesheet = new Stylesheet();
-        $stylesheet->name = 'Gbook module';
-        $stylesheet->value = $txt;  
-        $stylesheet->media_type = 'screen';
-        $stylesheetops->InsertStylesheet($stylesheet);
-    }
-}
-else
-{
-    $css = new CmsLayoutStylesheet;
-    $css->set_name('Gbook module');
-    $css->set_description('sample stylesheet for Gbook module');
-    $css->set_content($txt);
-    $css->save();
-}
+$css = new CmsLayoutStylesheet;
+$css->set_name('Gbook module');
+$css->set_description('sample stylesheet for Gbook module');
+$css->set_content($txt);
+$css->save();
+
 
 // create preferences
 $this->SetPreference('custom_modulename', $this->Lang('friendlyname'));
