@@ -36,16 +36,8 @@ $this->RemovePermission('Gbook: Modify');
 $this->DeleteTemplate();
 
 // remove stylesheet
-if (version_compare(CMS_VERSION, '1.99-alpha0', '<'))
-{
-    $stylesheetops = cmsms()->GetStylesheetOperations();
-    $stylesheetops->DeleteStylesheetByName('Gbook module');
-}
-else
-{
-    $css_ob = CmsLayoutStylesheet::load('Gbook module');
-    $css_ob->delete();
-}
+$css_ob = CmsLayoutStylesheet::load('Gbook module');
+$css_ob->delete();
 
 // remove all preferences
 $this->RemovePreference();
